summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kbudgetvaluesdecl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kbudgetvaluesdecl.cpp')
-rw-r--r--kmymoney2/widgets/kbudgetvaluesdecl.cpp130
1 files changed, 65 insertions, 65 deletions
diff --git a/kmymoney2/widgets/kbudgetvaluesdecl.cpp b/kmymoney2/widgets/kbudgetvaluesdecl.cpp
index 43d71f5..ac2e9f7 100644
--- a/kmymoney2/widgets/kbudgetvaluesdecl.cpp
+++ b/kmymoney2/widgets/kbudgetvaluesdecl.cpp
@@ -2,8 +2,8 @@
#include <klocale.h>
#ifndef KMM_I18N
#define KMM_I18N
-inline QString kmm_i18n(const char* msg, const char* ctx) { return i18n(ctx, msg); }
-inline QString kmm_i18n(const char* msg) { return i18n(msg); }
+inline TQString kmm_i18n(const char* msg, const char* ctx) { return i18n(ctx, msg); }
+inline TQString kmm_i18n(const char* msg) { return i18n(msg); }
#endif
/****************************************************************************
** Form implementation generated from reading ui file '../../../kmymoney2/widgets/kbudgetvaluesdecl.ui'
@@ -15,190 +15,190 @@ inline QString kmm_i18n(const char* msg) { return i18n(msg); }
#include "kbudgetvaluesdecl.h"
-#include <qvariant.h>
+#include <tqvariant.h>
#include <kmymoney/kmymoneyedit.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qwidgetstack.h>
+#include <tqpushbutton.h>
+#include <tqlabel.h>
+#include <tqwidgetstack.h>
#include <kpushbutton.h>
-#include <qbuttongroup.h>
-#include <qradiobutton.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+#include <tqbuttongroup.h>
+#include <tqradiobutton.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
/*
* Constructs a KBudgetValuesDecl as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-KBudgetValuesDecl::KBudgetValuesDecl( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+KBudgetValuesDecl::KBudgetValuesDecl( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
if ( !name )
setName( "KBudgetValuesDecl" );
- KBudgetValuesDeclLayout = new QGridLayout( this, 1, 1, 0, 6, "KBudgetValuesDeclLayout");
+ KBudgetValuesDeclLayout = new TQGridLayout( this, 1, 1, 0, 6, "KBudgetValuesDeclLayout");
m_amount10 = new kMyMoneyEdit( this, "m_amount10" );
- m_amount10->setProperty( "resetButtonVisibility", QVariant( FALSE, 0 ) );
+ m_amount10->setProperty( "resetButtonVisibility", TQVariant( FALSE, 0 ) );
KBudgetValuesDeclLayout->addWidget( m_amount10, 3, 5 );
m_amount6 = new kMyMoneyEdit( this, "m_amount6" );
- m_amount6->setProperty( "resetButtonVisibility", QVariant( FALSE, 0 ) );
+ m_amount6->setProperty( "resetButtonVisibility", TQVariant( FALSE, 0 ) );
KBudgetValuesDeclLayout->addWidget( m_amount6, 5, 3 );
m_amount5 = new kMyMoneyEdit( this, "m_amount5" );
- m_amount5->setProperty( "resetButtonVisibility", QVariant( FALSE, 0 ) );
+ m_amount5->setProperty( "resetButtonVisibility", TQVariant( FALSE, 0 ) );
KBudgetValuesDeclLayout->addWidget( m_amount5, 4, 3 );
- m_label6 = new QLabel( this, "m_label6" );
+ m_label6 = new TQLabel( this, "m_label6" );
KBudgetValuesDeclLayout->addWidget( m_label6, 5, 2 );
- m_label8 = new QLabel( this, "m_label8" );
+ m_label8 = new TQLabel( this, "m_label8" );
KBudgetValuesDeclLayout->addWidget( m_label8, 1, 4 );
m_amount9 = new kMyMoneyEdit( this, "m_amount9" );
- m_amount9->setProperty( "resetButtonVisibility", QVariant( FALSE, 0 ) );
+ m_amount9->setProperty( "resetButtonVisibility", TQVariant( FALSE, 0 ) );
KBudgetValuesDeclLayout->addWidget( m_amount9, 2, 5 );
m_amount11 = new kMyMoneyEdit( this, "m_amount11" );
- m_amount11->setProperty( "resetButtonVisibility", QVariant( FALSE, 0 ) );
+ m_amount11->setProperty( "resetButtonVisibility", TQVariant( FALSE, 0 ) );
KBudgetValuesDeclLayout->addWidget( m_amount11, 4, 5 );
- m_label12 = new QLabel( this, "m_label12" );
+ m_label12 = new TQLabel( this, "m_label12" );
KBudgetValuesDeclLayout->addWidget( m_label12, 5, 4 );
- m_label10 = new QLabel( this, "m_label10" );
+ m_label10 = new TQLabel( this, "m_label10" );
KBudgetValuesDeclLayout->addWidget( m_label10, 3, 4 );
- m_label7 = new QLabel( this, "m_label7" );
+ m_label7 = new TQLabel( this, "m_label7" );
KBudgetValuesDeclLayout->addWidget( m_label7, 0, 4 );
m_amount3 = new kMyMoneyEdit( this, "m_amount3" );
- m_amount3->setProperty( "resetButtonVisibility", QVariant( FALSE, 0 ) );
+ m_amount3->setProperty( "resetButtonVisibility", TQVariant( FALSE, 0 ) );
KBudgetValuesDeclLayout->addWidget( m_amount3, 2, 3 );
- m_label4 = new QLabel( this, "m_label4" );
+ m_label4 = new TQLabel( this, "m_label4" );
KBudgetValuesDeclLayout->addWidget( m_label4, 3, 2 );
m_amount12 = new kMyMoneyEdit( this, "m_amount12" );
- m_amount12->setProperty( "resetButtonVisibility", QVariant( FALSE, 0 ) );
+ m_amount12->setProperty( "resetButtonVisibility", TQVariant( FALSE, 0 ) );
KBudgetValuesDeclLayout->addWidget( m_amount12, 5, 5 );
- m_label3 = new QLabel( this, "m_label3" );
+ m_label3 = new TQLabel( this, "m_label3" );
KBudgetValuesDeclLayout->addWidget( m_label3, 2, 2 );
- m_label1 = new QLabel( this, "m_label1" );
+ m_label1 = new TQLabel( this, "m_label1" );
KBudgetValuesDeclLayout->addWidget( m_label1, 0, 2 );
- m_label2 = new QLabel( this, "m_label2" );
+ m_label2 = new TQLabel( this, "m_label2" );
KBudgetValuesDeclLayout->addWidget( m_label2, 1, 2 );
- m_label5 = new QLabel( this, "m_label5" );
+ m_label5 = new TQLabel( this, "m_label5" );
KBudgetValuesDeclLayout->addWidget( m_label5, 4, 2 );
- m_label11 = new QLabel( this, "m_label11" );
+ m_label11 = new TQLabel( this, "m_label11" );
KBudgetValuesDeclLayout->addWidget( m_label11, 4, 4 );
m_amount4 = new kMyMoneyEdit( this, "m_amount4" );
- m_amount4->setProperty( "resetButtonVisibility", QVariant( FALSE, 0 ) );
+ m_amount4->setProperty( "resetButtonVisibility", TQVariant( FALSE, 0 ) );
KBudgetValuesDeclLayout->addWidget( m_amount4, 3, 3 );
- m_label9 = new QLabel( this, "m_label9" );
+ m_label9 = new TQLabel( this, "m_label9" );
KBudgetValuesDeclLayout->addWidget( m_label9, 2, 4 );
m_amount8 = new kMyMoneyEdit( this, "m_amount8" );
- m_amount8->setProperty( "resetButtonVisibility", QVariant( FALSE, 0 ) );
+ m_amount8->setProperty( "resetButtonVisibility", TQVariant( FALSE, 0 ) );
KBudgetValuesDeclLayout->addWidget( m_amount8, 1, 5 );
m_amount2 = new kMyMoneyEdit( this, "m_amount2" );
- m_amount2->setProperty( "resetButtonVisibility", QVariant( FALSE, 0 ) );
+ m_amount2->setProperty( "resetButtonVisibility", TQVariant( FALSE, 0 ) );
KBudgetValuesDeclLayout->addWidget( m_amount2, 1, 3 );
m_amount7 = new kMyMoneyEdit( this, "m_amount7" );
- m_amount7->setProperty( "resetButtonVisibility", QVariant( FALSE, 0 ) );
+ m_amount7->setProperty( "resetButtonVisibility", TQVariant( FALSE, 0 ) );
KBudgetValuesDeclLayout->addWidget( m_amount7, 0, 5 );
- m_firstItemStack = new QWidgetStack( this, "m_firstItemStack" );
+ m_firstItemStack = new TQWidgetStack( this, "m_firstItemStack" );
- m_monthlyPage = new QWidget( m_firstItemStack, "m_monthlyPage" );
- m_monthlyPageLayout = new QHBoxLayout( m_monthlyPage, 0, 6, "m_monthlyPageLayout");
+ m_monthlyPage = new TQWidget( m_firstItemStack, "m_monthlyPage" );
+ m_monthlyPageLayout = new TQHBoxLayout( m_monthlyPage, 0, 6, "m_monthlyPageLayout");
m_amountMonthly = new kMyMoneyEdit( m_monthlyPage, "m_amountMonthly" );
- m_amountMonthly->setProperty( "resetButtonVisibility", QVariant( FALSE, 0 ) );
+ m_amountMonthly->setProperty( "resetButtonVisibility", TQVariant( FALSE, 0 ) );
m_monthlyPageLayout->addWidget( m_amountMonthly );
m_firstItemStack->addWidget( m_monthlyPage, 0 );
- m_yearlyPage = new QWidget( m_firstItemStack, "m_yearlyPage" );
- m_yearlyPageLayout = new QHBoxLayout( m_yearlyPage, 0, 6, "m_yearlyPageLayout");
+ m_yearlyPage = new TQWidget( m_firstItemStack, "m_yearlyPage" );
+ m_yearlyPageLayout = new TQHBoxLayout( m_yearlyPage, 0, 6, "m_yearlyPageLayout");
m_amountYearly = new kMyMoneyEdit( m_yearlyPage, "m_amountYearly" );
- m_amountYearly->setProperty( "resetButtonVisibility", QVariant( FALSE, 0 ) );
+ m_amountYearly->setProperty( "resetButtonVisibility", TQVariant( FALSE, 0 ) );
m_yearlyPageLayout->addWidget( m_amountYearly );
m_firstItemStack->addWidget( m_yearlyPage, 1 );
- m_individualPage = new QWidget( m_firstItemStack, "m_individualPage" );
- m_individualPageLayout = new QHBoxLayout( m_individualPage, 0, 6, "m_individualPageLayout");
+ m_individualPage = new TQWidget( m_firstItemStack, "m_individualPage" );
+ m_individualPageLayout = new TQHBoxLayout( m_individualPage, 0, 6, "m_individualPageLayout");
m_amount1 = new kMyMoneyEdit( m_individualPage, "m_amount1" );
- m_amount1->setProperty( "resetButtonVisibility", QVariant( FALSE, 0 ) );
+ m_amount1->setProperty( "resetButtonVisibility", TQVariant( FALSE, 0 ) );
m_individualPageLayout->addWidget( m_amount1 );
m_firstItemStack->addWidget( m_individualPage, 2 );
KBudgetValuesDeclLayout->addWidget( m_firstItemStack, 0, 3 );
- layout12 = new QVBoxLayout( 0, 0, 6, "layout12");
+ tqlayout12 = new TQVBoxLayout( 0, 0, 6, "tqlayout12");
m_clearButton = new KPushButton( this, "m_clearButton" );
- layout12->addWidget( m_clearButton );
- spacer7 = new QSpacerItem( 20, 21, QSizePolicy::Minimum, QSizePolicy::Expanding );
- layout12->addItem( spacer7 );
+ tqlayout12->addWidget( m_clearButton );
+ spacer7 = new TQSpacerItem( 20, 21, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
+ tqlayout12->addItem( spacer7 );
- KBudgetValuesDeclLayout->addMultiCellLayout( layout12, 0, 5, 1, 1 );
+ KBudgetValuesDeclLayout->addMultiCellLayout( tqlayout12, 0, 5, 1, 1 );
- m_periodGroup = new QButtonGroup( this, "m_periodGroup" );
+ m_periodGroup = new TQButtonGroup( this, "m_periodGroup" );
m_periodGroup->setColumnLayout(0, Qt::Vertical );
- m_periodGroup->layout()->setSpacing( 6 );
- m_periodGroup->layout()->setMargin( 11 );
- m_periodGroupLayout = new QVBoxLayout( m_periodGroup->layout() );
- m_periodGroupLayout->setAlignment( Qt::AlignTop );
+ m_periodGroup->tqlayout()->setSpacing( 6 );
+ m_periodGroup->tqlayout()->setMargin( 11 );
+ m_periodGroupLayout = new TQVBoxLayout( m_periodGroup->tqlayout() );
+ m_periodGroupLayout->tqsetAlignment( TQt::AlignTop );
- m_monthlyButton = new QRadioButton( m_periodGroup, "m_monthlyButton" );
+ m_monthlyButton = new TQRadioButton( m_periodGroup, "m_monthlyButton" );
m_periodGroupLayout->addWidget( m_monthlyButton );
- m_yearlyButton = new QRadioButton( m_periodGroup, "m_yearlyButton" );
+ m_yearlyButton = new TQRadioButton( m_periodGroup, "m_yearlyButton" );
m_periodGroupLayout->addWidget( m_yearlyButton );
- m_individualButton = new QRadioButton( m_periodGroup, "m_individualButton" );
+ m_individualButton = new TQRadioButton( m_periodGroup, "m_individualButton" );
m_periodGroupLayout->addWidget( m_individualButton );
- spacer10 = new QSpacerItem( 20, 21, QSizePolicy::Minimum, QSizePolicy::Expanding );
+ spacer10 = new TQSpacerItem( 20, 21, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
m_periodGroupLayout->addItem( spacer10 );
KBudgetValuesDeclLayout->addMultiCellWidget( m_periodGroup, 0, 5, 0, 0 );
languageChange();
- resize( QSize(553, 188).expandedTo(minimumSizeHint()) );
+ resize( TQSize(553, 188).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
// tab order
@@ -226,7 +226,7 @@ KBudgetValuesDecl::KBudgetValuesDecl( QWidget* parent, const char* name, WFlags
*/
KBudgetValuesDecl::~KBudgetValuesDecl()
{
// no need to delete child widgets, Qt does it all for us
}
/*
@@ -247,7 +247,7 @@ void KBudgetValuesDecl::languageChange()
m_label5->setText( kmm_i18n( "xxx" ) );
m_label11->setText( kmm_i18n( "xxx" ) );
m_label9->setText( kmm_i18n( "xxx" ) );
- m_clearButton->setText( QString::null );
+ m_clearButton->setText( TQString() );
m_periodGroup->setTitle( kmm_i18n( "Period" ) );
m_monthlyButton->setText( kmm_i18n( "Monthly" ) );
m_yearlyButton->setText( kmm_i18n( "Yearly" ) );
@@ -15,190 +15,190 @@ inline QString kmm_i18n(const char* msg) { return i18n(msg); }
/*
- * Constructs a KBudgetValuesDecl as a child of 'parent', with the
+ * Constructs a KBudgetValuesDecl as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
@@ -226,7 +226,7 @@ KBudgetValuesDecl::KBudgetValuesDecl( QWidget* parent, const char* name, WFlags
KBudgetValuesDecl::~KBudgetValuesDecl()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*